import React, {
  useState,
  useCallback,
  useEffect
} from 'react';
import ReactDOM from 'react-dom';
import { csv, arc, scaleBand, scaleLinear, max, format, scaleOrdinal } from 'd3';
import { useData } from './useData';
import { AxisBottom } from './AxisBottom';
import { AxisLeft } from './AxisLeft';
import { Marks } from './Marks';
import { ColorLegend } from './ColorLegend';
import { PlotMenu } from './PlotMenu'

 
const width = 960;
const height = 500;
const margin = {
  top: 20,
  right: 170,
  bottom: 105,
  left: 180,
};
const xAxisLabelOffset = 50;

const App = () => {
  const data = useData();
  
  const initialXAttribute = 'ActionsPTC';
  const [xAttribute, setXAttribute] = useState(initialXAttribute);
  const xValue = d => d[xAttribute];
  
  const initialX2Attribute = 'AmountPTC';
  const [x2Attribute, setX2Attribute] = useState(initialX2Attribute);
  const x2Value = d => d[x2Attribute];
  
  //console.log(x2Attribute)
  //console.log(xAttribute)

  if (!data) {
    return <pre>Loading...</pre>;
  }

  const innerHeight = height - margin.top - margin.bottom;
  const innerWidth = width - margin.left - margin.right;

  const xAxisLabel = '';
  //const xValue = (d) => d.ActionsPTC;
  

  
  //const x2Value = (d) => d.AmountPTC;
  const yValue = (d) => d.DonorType;
  const colorValue = ['COVID-19', 'Ostel svrhe'];
	
 // const xFirstRectValue = (d) => d.ActionsCOVID;
  const xFirstRectValue = initialX2Attribute == x2Attribute ? (d) => d.ActionsCOVID : (d) => d.Zero;
  //const xSecondRectValue = (d) => d.ActionsOTHER;
  const xSecondRectValue = initialX2Attribute == x2Attribute ? (d) => d.ActionsOTHER : (d) => d.Hundred;
  //const x2FirstRectValue = (d) => d.AmountCOVID;
  const x2FirstRectValue = initialX2Attribute == x2Attribute ? (d) => d.AmountCOVID : (d) => d.Zero;
  //const x2SecondRectValue = (d) => d.AmountOTHER;
  const x2SecondRectValue = initialX2Attribute == x2Attribute ? (d) => d.AmountOTHER : (d) => d.Hundred;
	
  console.log('x1:', xAttribute, 'initX1:', initialXAttribute )
  console.log('First rect:',xFirstRectValue)
  console.log('2nd rect:',xSecondRectValue)
  //console.log('x2:',x2Attribute, 'initX2:', initialX2Attribute )
  
  const yScale = scaleBand()
    .domain(data.map(yValue))
    .range([0, innerHeight])
    .padding(0.65);

  const xScale = scaleLinear()
    .domain([0, max(data, xValue)])
    .range([0, innerWidth]);
  
  const x2Scale = scaleLinear()
    .domain([0, max(data, x2Value)])
    .range([0, innerWidth]);
  
  const colorScale = scaleOrdinal()
    .domain(colorValue)
    .range(['#BD2D28', '#E6842A']);
  
  const scaleToPass = xScale.domain()[1] > x2Scale.domain()[1] ? xScale : x2Scale;
  
  return (
    <svg width={width} height={height}>
      <g
        transform={`translate(${margin.left}, ${margin.top})`}
      >
        <AxisBottom
          xScale={scaleToPass}
          innerHeight={innerHeight}
        />
        <AxisLeft yScale={yScale} />
        <text 
          className="axis-label"
          x={innerWidth / 2}
          y={innerHeight + xAxisLabelOffset}
          textAnchor={'middle'}
        >
          {xAxisLabel}
        </text>
        <Marks
          data={data}
          yScale={yScale}
          xScale={scaleToPass}
          xValue={xValue}
          x2Value={x2Value}
          yValue={yValue}
          xFirstRectValue={xFirstRectValue}
          xSecondRectValue={xSecondRectValue}
          x2FirstRectValue={x2FirstRectValue}
          x2SecondRectValue={x2SecondRectValue}
        />
        
      </g>
      <g transform={`translate(20, ${innerHeight + 60})`} >
        	<ColorLegend 
            tickSpacing={20}
  					tickSize={20}
  					tickTextOffset={30}
            colorScale={colorScale} 
          />
        </g>
      <g textAnchor="middle" transform={`translate(${width / 2}, ${height - 20})`}>
      	<PlotMenu updateXValue={setXAttribute} updateX2Value={setX2Attribute} />
      </g>
    </svg>
  );
};

const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
